# coding: utf-8
# Project：xbsTestTools
# File：test_ui_tools.py
# Author：张炼武
# Date ：2025/6/9 11:10
# IDE：PyCharm
class TestUiTools:
    def __init__(self, dev):
        self.dev = dev

    def skip_guide(self):
        """跳过引导"""
        ...

    def login_account(self):
        """登录账号"""
        ...